bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Handschrift C ## 5. Aventiure
___________________________________________________ #### Auentv wie Sivrit Chriemh' <alreste> ersach
| ### Man sach si tægeliche nv riten an den Rin ### di zer hochgecite gerne wolden sin ### die durch der chunige liebe chomen in daz lant ### man gap da genvogen bediv ross vn– ovch gewant
###### 267 | ### In was ir gesidele allen wol bereit ### den hohsten vn– den besten als uns daz ist geseit ### zwein vn– drizzech fursten da zer hohgecite ### da zierte sich engegene uil manic iuncfrowe sit
###### 268 | ### Ez was vil vnmvzzich Giselher daz chint ### die vremden vn– ir mage vil gvetliche sint ### enpfienger vn– Gernot vn– ovch ir beider man ### ia grvzten si die degene als ez nach eren was getan
###### 269 | ### Die golt varwen sætele si brahten in daz lant ### die zierlichen schilde vn– herlich gewant ### durch des wirtes liebe [11r]zv der hohgecit ### vil manigen vngesunden sach man vrolichen sit
###### 270 | ### Die in den peyen lagen vn– heten wnden not ### die mvsin des vergezzen wie herte was der tot ### die siechen vngesunden die mvsin si verklagen ### si frveten sich der mære gein der hohgecite tagen
###### 271 | ### wie si lebn wolden da zer wirtschaft ### wnne ane maze mit frevden vberchraft ### heten al die lute swaz man ir da vant ### des hvop sich michil wnne vber al daz Gvnthers lant
| ### An einem Pfienst morgen sach man fvr gan ### gekleidet wnnekliche vil manigen chunen man ### fvnf tusint oder mere da zer hohgecit ### der lop vil vollekliche an den Burgonden lit
###### 273 | ### Der wirt der het die sinne im was wol bekant ### wie rehte hercenliche der helt von Niderlant ### sine swester trvote swier si <niene> gesach ### der man so grozer schone vor allen iuncfrowen iach
###### 274 | ### Er sprach nv ratet alle mage vn– mine man ### wie wir die hochgecite so lobeliche han ### daz man vns drumbe iht schelte her nach dirre cit ### ein ieslich lop vil stæte ze iungest an den werchen lit
###### 275 | ### Do sprach vzer Mezzen der degen Ortewin ### welt ir mit vollen eren zer hochgecite sin ### so svlt ir lazen schowen div wnnekliehen kint ### die mit so vollen eren hie zen Burgonden sint
###### 276 | ### Waz were mannes wnne des frevte sich ir lip ### ez entæten schone meide vn– herlichiv wip ### ir lazet iwer swester fvr iwer geste gan ### der rat was ze liebe vil manigem degene getan
| ### Des wil ich gern volgen sprach der kunic do ### alle die ez erfunden die warns harte vro ### man saget ovch daz frovn Vten vn– ir tohter wolgetan ### daz si mit ir megeden hin ze hove solde gan
###### 278 | ### Do wart vz den chisten gesuchet gvot gewant ### swaz man in der valde der liehten wæte vant ### porten vn– povge des was in vil bereit ### sich ziert minnekliche vil manich wætlichiv meit
###### 279 | ### Vil manic reche tvmber des tages hete mvot ### daz er an ze sehene den frowen wære gvot ### daz er da fvr næme niht eines kuniges lant ### si sahen die vil gerne die si heten nie bekant
###### 280 | ### Do hiez der kunic riche mit siner swester gan ### die ir dienen solden wol hundert siner man ### ir vn– siner mage die trugen swert enhant ### daz was daz hofgesinde vzer Burgonden lant
###### 281 | ### <Voten> die vil richen die sah man mit ir chomen ### div hete frowen schone gesellechlich genomen ### wol hundert oder mere die trvgen richiv kleit ### nv gie mit Chriemh' vil manic wætlichiv meit
| ### Von einer kemenaten sach man si alle gan ### da wart vil michel schowen von rechen gar getan ### die des gedingen heten ob kunde daz geschehn ### daz si Chriemhilde solden vrolichen sehen
###### 283 | ### Nv gie div minnekliche also der morgenrot ### tvot vz den trvben wolchen da schiet [11v]von maniger not ### der si da trvg in hercen vn– lange het getan ### er sach die minneklichen nv vil herlichen stan
###### 284 | ### Ia luht ir von ir wæte vil manic edel stæin ### ir rosen rotiv varwe vil minnekliche schein ### swer so wnschen solde der <enkuende> niht geiehn ### daz er in dirre werlde hæte schoners iht gesehn
###### 285 | ### Sam der liehte mane vor den stern stat ### des schin so lutterliche ab den wolchen gat ### dem stvnt si vil geliche vor maniger frowen gvot ### des wart vil wol gehoehet den zieren heleden der mvot
| ### Die richen kamærere die sach vor in gan ### die hochgemvten degene dine wolden daz niht lan ### sine drungen da si sahen die minneklichen meit ### Sivride dem edelen was beidiv lieb vn– leit
###### 287 | ### Er daht in sinem mvote wie kunde daz ergan ### daz ich dich minnen solde als ich gedingen han ### sol aber ih dich vremden so wær ich sanfter tot ### er het von ir schulden tovgen lieb vn– not
###### 288 | ### Do stunt so minnekliche daz Sigemundes kint ### sam er entworfen wære an ein <permint> ### von gvter meister listen als man im do iach ### daz man helt deheinen so wætlichen nie gesach
###### 289 | ### Die mit Chriemhilde giengen die hiezen von den wegen ### wichen allenthalben daz leiste manic degn ### div hohe tragenden hercen frevten manigen lip ### man sach in grozen zvhten vil manic herlichez wip
###### 290 | ### Do sprach von Burgonden der herre Gernot ### der iv sinen dienest so minnekliche bot ### Gunther lieber bruder dem svlt ir tvn alsam ### vor allen disen degenen des rats ich nimmer mich gescham
###### 291 | ### Ir heizet Sifriden den Sigemundes svon ### gen zv Chriemhilde ob ir wol wellet tvon ### div nie gegruozte rechen div sol in grvzen pflegn ### da mit wir zeinem vriunde habn <den> zierlichen degn
| ### Do giengens wirtes mage da man den rechen vant ### si sprachen zv dem kunige vzer Niderlant ### der wirt hat iv erlovbet ir sult ze hove gan ### sin swester sol ivch grvezen daz ist zen eren iv getan
###### 293 | ### Do wart der degen gvote der mære vil gemeit ### ia truger in dem mvote lieb ane leit ### daz er sehn solde daz wnnekliche kint ### mit <minneklichen> tvgenden si grvzte Sifriden sint
###### 294 | ### Do si den hochgemvten vor ir stende sach ### do enzvnde sich ir varwe div schone magt sprach ### sit willekomen herre Sifrit ein edel ritter gvot ### do wart im von dem grvze vil wol gehoehet der mvot
###### 295 | ### Er neigir vlizzekliche bi henden si in vie ### wie rehte minnekliche der reche bi ir gie ### mit lieben ovgen blichen ein ander sahen an ### der herre vn– ovch div frowe daz wart tovgenlich getan
| ### Wart iht da frivntliche getwngen wiziv hant ### von hercenlieber minne daz ist mir vnbekant ### doch enmac ich niht gelovben daz ez wrde lan ### si het im holden willen harte schiere kunt getan
###### 297 | ### Bi der [12r]sumercite vn– gein des meyen tagen ### chvnder in sinem hercen nimmer me getragen ### minneklicher frevden denner ir do gewan ### do im div gie so nahen die er ze trvte wolde han
###### 298 | ### Do gedahte manic reche vn– wær mir sam geschehen ### daz ich ir gienge in hende sam ich in han gesehn ### oder bi ze ligene daz liez ich ane haz ### ez gediente noch nie reche nach einer kuniginne baz
###### 299 | ### Von swelher kunige landen die geste chomen dar ### die namen al gemeine niwan ir zweier war ### ir wart erlovbet kussen den wætlichen man ### im wart bi sinem lebene nie so liebe getan
| ### Der kunic uon Tenemarche der sprach sa zestvnt ### diss vil hohen grvzes lit maniger ungesvnt ### des ich vil wol enpfinde von Sifrides hant ### got enlaze in nimmer mere komen in miniv fursten lant
###### 301 | ### Do hiez man allenthalben wichen von den wegen ### den minneklichen frowen vil manigen chvenen degen ### sach man gezogenlichen ze hofe mit ir gan ### sit wart von ir gescheiden der vil wætlich man
###### 302 | ### Do gie si zv dem munster ir volgete manic wip ### do was ovch so gezieret der Chriemhilde lip ### daz da hoher wnsche maniger wart verlorn ### si was da zovgenweide vil manigem rechen geborn
###### 303 | ### Vil chvme erbeit Sifrit daz man da gesanc ### er mohte sinen sælden immer sagen danc ### daz im div was so wæge die er in hercen trvoch ### ovch was er der schonen holt von schulden genvoch
###### 304 | ### Do si chom fvr daz munster sam er ê hete getan ### man sahe in frivntliche zvo Chriemhilde gan ### do begvnde im danchen div vil schoniv meit ### daz er vor ir magen so rehte herlichen streit
| ### Nv lon iv got her Sifrit sprach daz schone kint ### daz ir daz habt verdienet daz iv die rechen sint ### so holt von warn schulden als ich si hore iehn ### do begunder minnekliche an vrovn Kriemehilden sehn
###### 306 | ### Ich sol in immer dienen also sprach der degn ### vn– enwil min hovbet nimmer ê gelegen ### ich engedien ir hulde als ich des willen han ### des ist ein teil frow Chriemhilt nach iwern hulden ergan
###### 307 | ### Inre tage zwelfen der tage al ieselich ### sach man bi dem rechen die maget lobelich ### so si ze hofe solde vor den fursten gan ### div ere wart dem degene durch groze liebe getan
###### 308 | ### Vrevde vn– wnne vil grozlichen schal ### sach man da tægeliche vor Guntheres sal ### dar voz vn– ovch dar inne von manigem chvnigen man ### Ortwin vn– Hagene grozer wnder da began
###### 309 | ### Swes iemen pflegen solde des warn si bereit ### mit volleklicher maze die helde vil gemeit ### des wrden von den gesten die rechen wol bekant ### da von was gezieret allez Guntheres lant
| ### Die ê da wnde lagen die sach man fur gan ### si wolden chuerzwilen mit des chuniges man ### schirmen [12v]mit den schilden vn– schiezen manigen schaft ### des hulfen in genvoge si heten grozliche kraft
###### 311 | ### In der hochgecite der wirt der hiez ir pflegn ### mit der besten spise er hete sich bewegn ### aller hande schande die ie kunic gewan ### man sach in minnekliche zvo den sinen gesten gan
###### 312 | ### Er sprach ir gvten degene e daz ir scheidet hin ### so nemt die mine gabe also stet min sin ### daz ich es immer diene versmæht niht min gvot ### daz wil ich mit iv teilen des han ich willigen mvot
###### 313 | ### Die von Tenemarche sprachen sa zehant ### e daz wir wider riten heim in unser lant ### wir gern stæter svone vn– gebn michel gvot ### vn– sezzen iv des sicherheit swie ivch des selben dunchet gvot
###### 314 | ### Livdegast geheilet siner wnden was ### der vogt von den Sahsen nach strite wol genas ### ettesliche toten <si> liezen dar enlant ### do gie der kunich Gvnther da er Sivriden vant
###### 315 | ### Er sprach zv dem degene nv rate wie ich tvo ### die unser widerwinnen wellent riten frvo ### vn– gernt stæter svone an mich un– mine man ### nv rata degen chvene waz dich des gvt dvnche getan
###### 316 | ### Waz mir die helde bieten daz wil ich dir sagen ### swaz funfhundert moere goldes mugen tragen ### daz <gæben> si mir gerne wold ich si ledich lan ### do sprach der herre Sivrit daz wære vil vbele getan
| ### Ir svlt si ledeklichen hinnen lazen varn ### vn– daz die rechen beide mere wol bewarn ### daz si immer mer geriten mit here in iwer lant ### des lat iv sicherheite tvn der beider herren hant
###### 318 | ### Des rates wil ich volgen da mite si giengen dan ### den sinen widerwinnen wart daz kunt getan ### ir goldes gerte niemen daz si da bvten ê ### da heime ir lieben frivnden was nach den hermvden we
###### 319 | ### Vil manige schilde volle man dar schazzes trvoch ### er teiltes ane wage den frivnden sin genvoch ### bi fvnfhundert marchen vn– eteslichen baz ### Gernot der vil chune der riet Gvnthere daz
###### 320 | ### Urlovp si alle namen also si wolden dan ### do sach man die rechen fvr Chriemhilde gan ### vn– ovch da frov <Vote> div kuniginne saz ### ez enwart noch nie degenen mere gevrlovbet baz
###### 321 | ### Herberge wrden lære do si von dannen riten ### noch bestvnt da heime mit ritterlichen siten ### der kunich mit sinen magen vil manic edel man ### die sach man nv tægeliche fvr frown Chriemh' gan
| ### Vrlovp ovch nemen wolde Sivrit der helet gvot ### ern trvote niht verenden des er da hete mvot ### der kunic daz sagen horte daz er wolde dan ### Giselher der iunge den degn vlegen do began
###### 323 | ### War woldet ir nv riten vil edel Sivrit ### belibet bi den degenen tvot des ich ivch bite ### bi Gvnthere dem kunige vn– ovch bi sinen man ### hie ist vil schoener frowen die sol man gerne ivch sehen lan
###### 324 | ### Do sprach der starche Sivrit div ross div lazet <stan> ### ich wolde hinnen riten des wil [13r]ich abe gan ### vn– traget ovch hin die schilde ia <wolde> ich in min lant ### des hat mich her Giselher mit grozen triwen erwant
###### 325 | ### Svs beleip der kune reche dvrch friwende liebe da ### ia wær er in den landen ninder anderswa ### gewesen also sanfte da von nv daz geschach ### daz er nv swenner wolde die schonen Chriemhilde sach
###### 326 | ### Durch ir vnmazen schoene der herre do beleip ### mit maniger kurcewile man im die zit vertreip ### wan daz in twanch ir minne div gab im dicke not ### dar vmbe sit der chvene lach vil iæmerliche tot
###### 327 | ### Iteniwc mære sich hvben vmben Rin ### ez sprachen zv dem kunige die hosten mage sin ### warvmbe er niht ennæme ein wip zv siner ê ### do sprach der chunic riche ine wil niht langer biten me
###### 328 | ### Des wil ich beraten wa ich die mvge nemen ### div mir vn– mime riche ze frowen mvge zemen ### an edel vn– ovch an schone der gib ich miniv lant ### als ich die reht ervinde si sol iv werden wol bekant

<<< Übersicht <<< vorige Seite nächste Seite >>>